<?php
/*
 * génération des fichiers preseed pour debian
 */
require "config.inc.php";
require "ldap.inc.php";
require "actions.inc.php";
require "ipxe_functions.inc.php";

header("Content-type: text/plain");
$mode = $_POST['mode'] ?? $_GET['mode'] ?? "";
$token = $_POST['token'] ?? $_GET['token'];
$mac = $_POST['mac'] ?? $_GET['mac'];
$os = $_POST['os'] ?? $_GET['os'] ?? "debian";
$type = $_POST['type'] ?? $_GET['type'] ?? $config['environnement_bureau'] ?? "base";
$perso = $_POST['perso'] ?? $_GET['perso'] ?? false;

// Lire le fichier preseed générique et le compléter (sections 3, 5, 8 et 10)
if (auth_action($config, $mac, $token)) {
    $machine = get_action($config, $mac);
    if (isset($machine['cn'])) {
        if ($type == "se4ad") {
            $file = file(__DIR__ . "/se4ad.cfg");
            $se4ad_slave_ip = explode(".", $config['se4ad_ip']);
            $config['se4ad_slave_ip'] = $config['se4ad_slave_ip'] ?? implode(".", [
                $se4ad_slave_ip[0],
                $se4ad_slave_ip[1],
                $se4ad_slave_ip[2],
                $se4ad_slave_ip[3] + 2
            ]);
        } elseif ($type == "se4fs") {
            if (preg_match("/^se4fs-([0-9]{7}[a-zA-Z])$/", $machine['cn'], $m)) {
                $config['etab_ou'] = $m[1];
                $config['se4_priv_key'] = base64_encode(file_get_contents("/etc/sambaedu/id_rsa"));
            }
            // uniquement pour les config multi-établissements
            // on demandera l'UAI de l'établissement lors de l'installation et son ip fixe
            $file = file(__DIR__ . "/se4fs.cfg");
        } elseif ($os == 'ubuntu') {
            $file = file(__DIR__ . "/ubuntu.cfg");
            if (@is_dual_boot($config, $machine)) {
                $file = array_merge($file, file(__DIR__ . "/double_boot.cfg"));
            } else {
                $file = array_merge($file, file(__DIR__ . "/simple_boot.cfg"));
                remove_dual_boot($config, $machine['cn']);
                set_os($config, $machine['cn'], "linux");
            }
        } else {
            $file = [];
            // gestion presence-absence du cache apt (section 3)
            if (! empty($config['apt_proxy'])) {
                $file = array_merge($file, file(__DIR__ . "/aptcache.cfg"));
            } else {
                if ($config['server_proxy'] == "1") {
                    $file = array_merge($file, file(__DIR__ . "/proxy.cfg"));
                }
                $file = array_merge($file, file(__DIR__ . "/nocache.cfg"));
            }
            if ($perso) {
                if ($type = "base") {
                    $file = array_merge($file, file(__DIR__ . "/debian_serv.cfg"));
                } else {
                    $file = array_merge($file, file(__DIR__ . "/debian_perso.cfg"));
                }
            } else {
                $file = array_merge($file, file(__DIR__ . "/debian.cfg"));
                // choix de l'environnement de bureau gnome ou lxde (section 8)
                // gnome ou lxde
                switch ($type) {
                    case 'gnome':
                        $file = array_merge(file(__DIR__ . "/debian_gnome.cfg"), $file);
                        break;
                    case 'lxde':
                        $file = array_merge(file(__DIR__ . "/debian_lxde.cfg"), $file);
                        break;
                    case 'kde':
                        $file = array_merge(file(__DIR__ . "/debian_kde.cfg"), $file);
                        break;
                    case 'mate':
                        $file = array_merge(file(__DIR__ . "/debian_mate.cfg"), $file);
                        break;
                    case 'xfce':
                        $file = array_merge(file(__DIR__ . "/debian_xfce.cfg"), $file);
                        break;
                    case 'cinnamon':
                        $file = array_merge(file(__DIR__ . "/debian_cinnamon.cfg"), $file);
                        break;
                    default:
                        $file = array_merge(file(__DIR__ . "/debian_base.cfg"), $file);
                        break;
                }
                $file = array_merge($file, file(__DIR__ . "/sambaedu.cfg"));
                // lancement éventuellement d'une commande à la fin (section 10)
                // une commande → 1 ou pas de commande → 0
                if (! empty($config['commande_fin_preseed'])) {
                    $file = array_merge($file, file(__DIR__ . "/commande_fin.cfg"));
                }
            }
            // choix de simple ou du double boot (section 5)
            // simple_boot.cfg ou double_boot.cfg
            if (@is_dual_boot($config, $machine)) {
                $file = array_merge($file, file(__DIR__ . "/double_boot.cfg"));
            } else {
                $file = array_merge($file, file(__DIR__ . "/simple_boot.cfg"));
                remove_dual_boot($config, $machine['cn']);
                set_os($config, $machine['cn'], "linux");
                // on impose un dev si défini dans la conf
                if (! empty($config['linux_disk'])) {
                    $file[] = "d-i partman-auto/disk string " . $config['linux_disk'];
                }
            }
        }
        // initialisation des parametres présents dans sambaedu.conf
        if (empty($config['linux_interface'])) {
            $config['linux_interface'] = "auto";
        }
        if (empty($config['version_debian'])) {
            $config['version_debian'] = "bullseye";
        }
        write_param($config, $file);
        // parametres spécifiques au poste
        $params = array(
            'hostname' => strtolower($machine['cn']),
            'token' => $token
        );
        write_param($params, $file);
        $preseed = "";
        foreach ($file as $ligne) {
            $preseed .= $ligne;
        }
        echo $preseed;
        set_action($config, $machine['cn'], "default", "", "", "linux", "default", - 1);
        file_put_contents("/tmp/" . $machine['cn'] . ".preseed", $preseed);
    }
}
?>
